@@ -8,6 +8,14 @@ test_that("Can slice with one instance",{
 	expect_true(!is.na(match(res, "asdfasdf <- dat[[1,2]]")))
 	
 	
+})
+test_that("Dont convert floating point numbers",{
+	matLine <- "asdfasdf <- 5.4"
+	mp <- makeSliceMap(matClass = "structure", rClass = "list")
+	res <- mp(matLine)
+	expect_true(!is.na(match(res, "asdfasdf <- 5.4")))
+	
+	
 })
 
 test_that("Can slice with Structures",{
