@@ -10,3 +10,10 @@ test_that("Dictionary switcher works",{
 	expect_equal(swc(c("meh", "badSort", "do this too")), 4)
 	expect_equal(swc(c("meh", "badSort")), 5)
 })
+
+test_that("length out switch works", {
+	test <- list("if length(out) == 1L", "if length(out) == 2L")
+	swc <- makeFunSwitcher(test)
+	expect_equal(swc(c("meh", "badSort"), numOut = 2), 2)
+	expect_equal(swc(c("meh", "badSort"), numOut = 1), 1)
+})
